# RPM spec file for GHC					         -*-rpm-spec-*-
#
# Copyright [1998..2003] The GHC Team
#
# Thanks to Zoltan Vorosbaranyi <vbzoli@vbzo.li> for suggestions in 
# earlier versions and Pixel <pixel@mandrakesoft.com> for coding tips.
#
# This file is subject to the same free software license as GHC.

%define build_version 6.2

Summary: Glasgow Haskell Compilation system
Name: ghc
Version: 6.2
Release: 1
Packager: Jens Petersen <petersen@haskell.org>
Copyright: BSD style w/o adv. clause
Group: Development/Languages
Source0: http://haskell.org/ghc/dist/%{version}/ghc-%{version}-src.tar.bz2
NoSource: 0
URL: http://haskell.org/ghc/
BuildRoot: /var/tmp/%{name}-%{version}-root
Requires: gcc gmp-devel
BuildRequires: ghc = %{build_version}, haddock, docbook-utils, flex
BuildRequires: gmp-devel, readline-devel
Provides: haskell, GHC = %{version}

%description
Haskell is the standard purely functional programming language; the
current language version is Haskell 98, agreed in December 1998.

GHC is a state-of-the-art programming suite for Haskell.  Included is
an optimising compiler generating good code for a variety of
platforms, together with an interactive system for convenient, quick
development.  The distribution includes space and time profiling
facilities, a large collection of libraries, and support for various
language extensions, including concurrency, exceptions, and foreign
language interfaces (C, C++, etc).

A wide variety of Haskell related resources (tutorials, libraries,
specifications, documentation, compilers, interpreters, references,
contact information, links to research groups) are available from the
Haskell home page at <http://www.haskell.org/>.

%package prof
Summary: Profiling libraries for GHC
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}
Provides: GHC-prof = %{version}

%description prof
Profiling libraries for Glorious Glasgow Haskell Compilation System (GHC).
They should be installed when GHC's profiling subsystem is needed.

%package doc
Summary: Documentation for GHC
Group: Documentation

%description doc
Preformatted documentation for the Glorious Glasgow Haskell Compilation System 
(GHC) and its libraries.  It should be installed if you like to have local
access to the documentation in PostScript and HTML format.  Alternatively,
the documentation is available online at

  http://haskell.org/ghc/documentation.html

# the debuginfo subpackage is currently empty anyway, so don't generate it
%define debug_package %{nil}
%define __spec_install_post /usr/lib/rpm/brp-compress

%prep
%setup -q -n ghc-%{version}

# generate our own `build.mk'
cat >mk/build.mk <<END
#GhcLibWays =
GhcWithInterpreter=YES
END

%build
# run autoconf if necessary
[ ! -x configure ] && autoconf && cd ghc && autoconf
./configure --prefix=%{_prefix} --with-ghc=ghc-%{build_version}
#make %{?_smp_mflags} boot
make all

%install
rm -rf $RPM_BUILD_ROOT

make prefix=$RPM_BUILD_ROOT%{_prefix} install

make datadir=$RPM_BUILD_DIR/ghc-%{version} SGMLDocWays="html" install-docs

SRC_TOP=$PWD
rm -f rpm-*-filelist rpm-*.files
( cd $RPM_BUILD_ROOT
  find .%{_libdir} \( -type d -fprintf $SRC_TOP/rpm-dir.files "%%%%dir %%p\n" \) -o \( -type f \( -name '*.p_hi' -o -name '*_p.a' \) -fprint $SRC_TOP/rpm-prof.files \) -o \( -not -name 'package.conf' -fprint $SRC_TOP/rpm-lib.files \)
)

# make paths absolute (filter "./usr" to "/usr")
perl -pi -e "s|\.%{_prefix}|%{_prefix}|" rpm-*.files

cat rpm-dir.files rpm-lib.files > rpm-base-filelist
cat rpm-dir.files rpm-prof.files > rpm-prof-filelist

%clean
rm -rf $RPM_BUILD_ROOT

%files -f rpm-base-filelist
%defattr(-,root,root)
%{_bindir}/*
%config(noreplace) %{_libdir}/ghc-%{version}/package.conf
%doc ghc/ANNOUNCE ghc/README

%files prof -f rpm-prof-filelist
%defattr(-,root,root)

%files doc
%defattr(-,root,root)
%doc html

%changelog
* Wed Dec 17 2003 Jens Petersen <petersen@haskell.org> - 6.2-1
- 6.2

* Wed Jul 30 2003 Jens Petersen <petersen@haskell.org> - 6.0.1-1
- 6.0.1
- distinguish version and build_version

* Thu Jun 19 2003 Jens Petersen <petersen@haskell.org> - 6.0-8
- buildrequire GHC = %{version}
- provide GHC and GHC-prof

* Wed Jun 18 2003 Jens Petersen <petersen@haskell.org> - 6.0-7
- remove redundant provides and obsoletes 
- drop -utils subpackage

* Mon Jun 16 2003 Jens Petersen <petersen@haskell.org> - 6.0-6
- bring back bindir symlinks for main package
- remove post and preun scripts
- build with ghc-%{version}

* Thu Jun 12 2003 Jens Petersen <petersen@haskell.org>
- add explicit obsoletes to the subpackages
- don't make debuginfo subpackage, since it is empty anyway

* Wed Jun 11 2003 Jens Petersen <petersen@haskell.org>
- make package renamable to allow easier parallel installation and updating
  - provide ghc
  - dont use %%name when installing html in topdir
- fix dependencies
  - require gmp-devel again
  - require gcc (which requires glibc-devel, so don't need to require
    /usr/lib/libdl.so any more)
- move this changelog to end

* Tue Jun 10 2003 Jens Petersen <petersen@haskell.org> - 6.0-5
- require /usr/lib/libdl.so (provided by glibc-devel)
- tweak post script for bindir symlinks in the hope that it will
  now work for upgrades

* Mon Jun  9 2003 Jens Petersen <petersen@haskell.org> - 6.0-4
- require gmp and buildrequire gmp-devel
- add -utils subpackage for un-versioned bindir programs
- don't include unversioned symlinks in the bindir manifest
- generate un-versioned symlinks at install time if they don't exist
  and remove when uninstalling
- fix file ownership

* Fri Jun  6 2003 Jens Petersen <petersen@haskell.org> - 6.0-3
- bring back prof libs

* Thu Jun  5 2003 Jens Petersen <petersen@haskell.org> - 6.0-2
- rebuild with ghc-6.0
- include directories in filelist with %%dir

* Mon Jun  2 2003 Jens Petersen <petersen@haskell.org> - 6.0-1
- update to 6.0 release
- spec cleanup
- don't build prof libs for now
- simplify filelist generation

* Wed Sep 26 2001 Manuel Chakravarty
- small changes for 5.04

* Wed Sep 26 2001 Manuel Chakravarty
- split documentation off into a separate package
- adapt to new docbook setup in RH7.1

* Mon Apr 16 2001 Manuel Chakravarty
- revised for 5.00
- also runs autoconf automagically if no ./configure found

* Thu Jun 22 2000 Sven Panne
- removed explicit usage of hslibs/docs, it belongs to ghc/docs/set

* Sun Apr 23 2000 Manuel Chakravarty
- revised for ghc 4.07; added suggestions from Pixel <pixel@mandrakesoft.com>
- added profiling package

* Tue Dec 7 1999 Manuel Chakravarty
- version for use from CVS

* Thu Sep 16 1999 Manuel Chakravarty
- modified for GHC 4.04, patchlevel 1 (no more 62 tuple stuff); minimises use
  of patch files - instead emits a build.mk on-the-fly

* Sat Jul 31 1999 Manuel Chakravarty
- modified for GHC 4.04

* Wed Jun 30 1999 Manuel Chakravarty
- some more improvements from vbzoli

* Fri Feb 26 1999 Manuel Chakravarty
- modified for GHC 4.02

* Thu Dec 24 1998 Zoltan Vorosbaranyi 
- added BuildRoot
- files located in /usr/local/bin, /usr/local/lib moved to /usr/bin, /usr/lib

* Tue Jul 28 1998 Manuel Chakravarty
- original version
